@@ -1,15 +1,12 @@
 """
-    Generic CSV dataset format.
+    CSV (comma separated value) dataset format.
 """
 import logging
 from pathlib import Path
-from typing import List, Union, Callable
+from typing import Callable, List, Union
 
 import gin
-
 import zpy
-from zpy.output import Output
-from zpy.saver_image import ImageSaver
 
 log = logging.getLogger(__name__)
 
@@ -20,18 +17,31 @@ class CSVParseError(Exception):
 
 
 @gin.configurable
-class OutputCSV(Output):
-    """Holds the logic for outputting CSV annotations to file."""
+class OutputCSV(zpy.output.Output):
+    """ Output class for CSV (comma separated value) style annotations."""
 
     ANNOTATION_FILENAME = Path('annotations.csv')
 
+    def __init__(self, *args, **kwargs) -> Path:
+        super().__init__(*args, annotation_filename=self.ANNOTATION_FILENAME, **kwargs)
+
     @gin.configurable
     def output_annotations(self,
+                           annotation_path: Union[Path, str] = None,
                            annotation_dict_to_csv_row_func: Callable = None,
-                           annotation_path: Union[str, Path] = None,
                            header: List[str] = None,
-                           ):
-        """ Ouput Generic CSV annotations. """
+                           ) -> Path:
+        """ Output CSV annotations to file.
+
+        Args:
+            annotation_path (Union[Path, str], optional): Output path for annotation file.
+            annotation_dict_to_csv_row_func (Callable, optional): Function that converts an annotation dict to a csv row. Defaults to None.
+            header (List[str], optional): Column headers. Defaults to None.
+
+        Returns:
+            Path: Path to annotation file.
+        """
+        annotation_path = super().output_annotations(annotation_path=annotation_path)
         if annotation_dict_to_csv_row_func is None:
             raise CSVParseError(
                 'Output CSV annotations requires a annotation_dict_to_csv_row_func')
@@ -42,24 +52,25 @@ class OutputCSV(Output):
             row = annotation_dict_to_csv_row_func(annotation, saver=self.saver)
             if row is not None:
                 csv_data.append(row)
-        # Get the correct annotation path
-        if annotation_path is not None:
-            annotation_path = annotation_path
-        elif self.saver.annotation_path is None:
-            annotation_path = self.saver.output_dir / self.ANNOTATION_FILENAME
-        else:
-            annotation_path = self.saver.annotation_path
         # Write out annotations to file
         zpy.files.write_csv(annotation_path, csv_data)
         # Verify annotations
         parse_csv_annotations(annotation_path)
+        return annotation_path
 
 
 @gin.configurable
 def parse_csv_annotations(
-    annotation_file: Union[str, Path],
+    annotation_file: Union[Path, str],
 ) -> None:
-    """ Parse CSV annotations """
+    """ Parse CSV annotations.
+
+    Args:
+        annotation_file (Union[Path, str]): Path to annotation file.
+
+    Raises:
+        CSVParseError: Rows not same length.
+    """
     log.info(f'Verifying CSV annotations at {annotation_file}...')
     csv_data = zpy.files.read_csv(annotation_file)
     # Make sure all the rows are the same length
@@ -72,3 +83,4 @@ def parse_csv_annotations(
     if not all(len(l) == length for l in csv_data_iterable):
         raise CSVParseError(
             f'Not all rows in the CSV have same length {length}')
+    # TODO: Return Saver object.
